"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ColumnContainer = void 0;
var _styledComponents = _interopRequireDefault(require("styled-components"));
var _mediaQuery = require("../../shared/media-query/media-query.js");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const calculateChildrens = size => {
  const childrens = Math.round(100 / size.replace('%', ''));
  return childrens === 1 ? childrens + 1 : childrens;
};
const getDisplay = size => size === '0%' ? 'none' : 'block';
const ColumnContainer = _styledComponents.default.div`
  --childrens-xs: ${({
  size
}) => calculateChildrens(size.xs)};
  --childrens-sm: ${({
  size
}) => calculateChildrens(size.sm)};
  --childrens-md: ${({
  size
}) => calculateChildrens(size.md)};
  --childrens-lg: ${({
  size
}) => calculateChildrens(size.lg)};

  width: ${({
  size,
  theme
}) => size.xs !== '100%' ? `calc(${size.xs} - (${theme.tokens.flexbox.XS} * (var(--childrens-xs) - 1)) / var(--childrens-xs))` : '100%'};

  display: ${({
  size
}) => getDisplay(size.xs)};

  @media ${_mediaQuery.MediaQueries.SM} {
    width: ${({
  size,
  theme
}) => size.sm !== '100%' ? `calc(${size.sm} - (${theme.tokens.flexbox.S} * (var(--childrens-sm) - 1)) / var(--childrens-sm))` : '100%'};

    display: ${({
  size
}) => getDisplay(size.sm)};
  }

  @media ${_mediaQuery.MediaQueries.MD} {
    width: ${({
  size,
  theme
}) => size.md !== '100%' ? `calc(${size.md} - (${theme.tokens.flexbox.M} * (var(--childrens-md) - 1)) / var(--childrens-md))` : '100%'};

    display: ${({
  size
}) => getDisplay(size.md)};
  }

  @media ${_mediaQuery.MediaQueries.LG} {
    width: ${({
  size,
  theme
}) => size.lg !== '100%' ? `calc(${size.lg} - (${theme.tokens.flexbox.M} * (var(--childrens-lg) - 1)) / var(--childrens-lg))` : '100%'};

    display: ${({
  size
}) => getDisplay(size.lg)};
  }
`;
exports.ColumnContainer = ColumnContainer;