"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.components = void 0;
var _index = require("../tokens/index.js");
var _colors = require("./colors.js");
var _effects = require("./effects.js");
var _spacing = require("./spacing.js");
var _typography = require("./typography.js");
const theme = {
  ..._colors.colors,
  ..._effects.effects,
  ..._spacing.spacing,
  ..._typography.typography
};
const components = {
  button: {
    transaction: {
      container: {
        color: {
          default: theme.background.transaction,
          hover: theme.backgroundState.transaction.hover,
          active: theme.backgroundState.transaction.active,
          disable: theme.backgroundState.transaction.disable
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disable: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disable: theme.contentState.base.disable
        }
      }
    },
    sm: {
      generic: {
        paddingHorizontal: _index.tokens.padding.S,
        paddingVertical: _index.tokens.padding.S,
        gap: _index.tokens.padding.S,
        textLabel: theme.desktop.button.tertiary,
        borderRadius: _index.tokens.borderRadius.XS
      },
      icon: {
        size: '18px'
      },
      ghost: {
        paddingHorizontal: _index.tokens.padding.NONE,
        paddingVertical: _index.tokens.padding.S,
        gap: _index.tokens.padding.S,
        textLabel: theme.desktop.button.tertiary,
        borderRadius: _index.tokens.borderRadius.XS
      }
    },
    md: {
      generic: {
        paddingHorizontal: _index.tokens.padding.M,
        paddingVertical: _index.tokens.padding.M,
        gap: _index.tokens.padding.M,
        borderRadius: _index.tokens.borderRadius.XS,
        textLabel: theme.desktop.button.secondary
      },
      icon: {
        size: '24px'
      },
      ghost: {
        paddingHorizontal: _index.tokens.padding.NONE,
        paddingVertical: _index.tokens.padding.M,
        gap: _index.tokens.padding.M,
        textLabel: theme.desktop.button.secondary,
        borderRadius: _index.tokens.borderRadius.XS
      }
    },
    lg: {
      generic: {
        paddingHorizontal: _index.tokens.padding.L,
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.L,
        borderRadius: _index.tokens.borderRadius.XS,
        textLabel: theme.desktop.button.primary
      },
      icon: {
        size: '24px'
      },
      ghost: {
        paddingHorizontal: _index.tokens.padding.NONE,
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.L,
        textLabel: theme.desktop.button.primary,
        borderRadius: _index.tokens.borderRadius.XS
      }
    },
    brand: {
      container: {
        color: {
          default: theme.background.accent,
          hover: theme.backgroundState.accent.hover,
          active: theme.backgroundState.accent.active,
          disable: theme.backgroundState.accent.disable
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disable: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.content.base,
          active: theme.content.base,
          disable: theme.contentState.base.disable
        }
      }
    },
    alternative: {
      container: {
        color: {
          default: theme.background.dark,
          hover: theme.backgroundState.dark.hover,
          active: theme.backgroundState.dark.active,
          disable: theme.backgroundState.dark.disable
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.baseInverse,
          hover: theme.content.baseInverse,
          active: theme.content.baseInverse,
          disable: theme.contentState.baseInverse.disable
        }
      },
      icon: {
        color: {
          default: theme.content.baseInverse,
          hover: theme.content.baseInverse,
          active: theme.content.baseInverse,
          disable: theme.contentState.baseInverse.disable
        }
      }
    },
    outline: {
      container: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        },
        border: {
          default: theme.border.dark,
          hover: theme.borderState.dark.hover,
          active: theme.borderState.dark.active,
          disable: theme.borderState.dark.disable
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disable: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disable: theme.contentState.base.disable
        }
      }
    },
    ghost: {
      container: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disable: theme.contentState.base.disable
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          hover: theme.contentState.base.hover,
          active: theme.contentState.base.active,
          disable: theme.contentState.base.disable
        }
      }
    }
  },
  input: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    borderRadius: theme.borderRadius.none,
    fieldLabel: theme.desktop.input.secondary,
    required: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    error: theme.desktop.input.secondary,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          error: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    }
  },
  dropdown: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          error: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    borderRadius: theme.borderRadius.none,
    fieldLabel: theme.desktop.input.secondary,
    error: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    required: theme.desktop.input.secondary
  },
  select: {
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.M,
    container: {
      color: {
        default: theme.background.base,
        hover: theme.background.accentLight,
        active: theme.background.accentLight,
        header: theme.background.weak,
        disable: theme.background.base
      }
    },
    text: {
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        active: theme.content.base,
        header: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    gap: '0px',
    borderRadius: theme.borderRadius.none,
    fieldLabel: theme.desktop.body.secondary
  },
  table: {
    rowTable: {
      text: {
        default: theme.desktop.body.secondary
      }
    },
    titleHeader: {
      text: {
        default: theme.desktop.label.primary,
        color: theme.content.base
      },
      gap: _index.tokens.padding.S,
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L
    },
    container: {
      border: {
        color: {
          default: theme.border.base
        }
      },
      background: {
        color: {
          default: theme.background.weak
        }
      }
    },
    labelRow: {
      text: {
        color: {
          text: {
            color: theme.content.base
          }
        }
      },
      icon: {
        color: {
          default: theme.content.base
        }
      }
    },
    iconSort: {
      color: {
        active: theme.content.base,
        default: theme.backgroundState.dark.disable
      }
    },
    sortIcon: {
      size: {
        default: '12px'
      }
    },
    labelRowTable: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.M
    }
  },
  radioButton: {
    radioGroup: {
      gap: _index.tokens.padding.L
    },
    gap: _index.tokens.padding.S,
    circle: {
      color: {
        default: theme.border.dark,
        hover: theme.border.dark,
        selected: theme.border.dark,
        focus: theme.border.dark,
        error: theme.border.danger,
        disableSelected: theme.borderState.dark.disable,
        disable: theme.borderState.dark.disable
      }
    },
    innerCircle: {
      color: {
        default: _index.tokens.null['100'],
        hover: theme.backgroundState.dark.hover,
        selected: theme.background.dark,
        focus: theme.background.dark,
        error: _index.tokens.null['100'],
        disableSelected: theme.backgroundState.dark.disable,
        disable: _index.tokens.null['100']
      }
    },
    focus: {
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100'],
        selected: _index.tokens.null['100'],
        focus: theme.border.accent,
        error: _index.tokens.null['100'],
        selectedDisable: _index.tokens.null['100'],
        disable: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        textLabel: {
          default: theme.content.base,
          hover: theme.content.base,
          selected: theme.content.base,
          focus: theme.content.base,
          error: theme.content.base,
          disableSelected: theme.contentState.base.disable,
          disable: theme.contentState.base.disable
        },
        errorLabel: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          selected: _index.tokens.null['100'],
          focus: _index.tokens.null['100'],
          error: theme.content.danger,
          disableSelected: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      }
    },
    fieldLabel: theme.desktop.label.secondary,
    errorLabel: theme.desktop.label.tertiary
  },
  checkbox: {
    gap: _index.tokens.padding.S,
    square: {
      color: {
        default: theme.border.dark,
        hover: theme.border.dark,
        selected: theme.border.dark,
        hoverSelected: theme.border.dark,
        focus: theme.border.dark,
        error: theme.border.danger,
        disableSelected: theme.borderState.dark.disable,
        disable: theme.borderState.dark.disable
      }
    },
    innerSquare: {
      color: {
        default: _index.tokens.null['100'],
        hover: theme.backgroundState.dark.hover,
        selected: theme.background.dark,
        hoverSelected: theme.backgroundState.dark.hover,
        focus: theme.background.dark,
        error: _index.tokens.null['100'],
        disableSelected: theme.backgroundState.dark.disable,
        disable: _index.tokens.null['100']
      }
    },
    focus: {
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100'],
        selected: _index.tokens.null['100'],
        hoverSelected: _index.tokens.null['100'],
        focus: theme.border.accent,
        error: _index.tokens.null['100'],
        selectedDisable: _index.tokens.null['100'],
        disable: _index.tokens.null['100']
      }
    },
    checkmark: {
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100'],
        selected: theme.background.base,
        hoverSelected: theme.background.base,
        focus: theme.background.base,
        error: _index.tokens.null['100'],
        selectedDisable: theme.backgroundState.base.disable,
        disable: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        textLabel: {
          default: theme.content.base,
          hover: theme.content.base,
          selected: theme.content.base,
          hoverSelected: theme.content.base,
          focus: theme.content.base,
          error: theme.content.base,
          disableSelected: theme.contentState.base.disable,
          disable: theme.contentState.base.disable
        },
        errorLabel: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          selected: _index.tokens.null['100'],
          hoverSelected: _index.tokens.null['100'],
          focus: _index.tokens.null['100'],
          error: theme.content.danger,
          disableSelected: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      }
    },
    fieldLabel: theme.desktop.label.secondary,
    errorLabel: theme.desktop.label.tertiary
  },
  segmentControl: {
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding['M+'],
    gap: _index.tokens.padding.NONE,
    error: theme.desktop.label.tertiary,
    container: {
      color: {
        default: theme.background.base,
        pressed: theme.background.accentLight,
        pressedError: theme.background.dangerLight
      }
    },
    text: {
      color: {
        default: theme.content.base,
        pressed: theme.content.base,
        error: theme.content.danger
      }
    },
    border: {
      color: {
        default: theme.border.subtle,
        pressed: theme.border.subtle,
        pressedError: theme.border.danger
      }
    },
    fieldLabel: theme.desktop.label.secondary
  },
  tabs: {
    basic: {
      paddingHorizontal: _index.tokens.padding['L+'],
      paddingVertical: _index.tokens.padding['M+'],
      gap: _index.tokens.padding.XS,
      container: {
        color: {
          default: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.subtle,
          active: theme.content.base,
          hover: theme.content.base,
          disable: theme.contentState.base.disable
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100'],
          active: theme.border.accent,
          hover: theme.border.base,
          disable: _index.tokens.null['100']
        }
      },
      borderRadius: theme.borderRadius.none,
      fieldLabel: theme.desktop.label.secondary,
      outsideBorder: {
        color: {
          generic: theme.border.subtle
        }
      }
    },
    card: {
      paddingHorizontal: _index.tokens.padding['L+'],
      paddingVertical: _index.tokens.padding['M+'],
      gap: _index.tokens.padding.NONE,
      container: {
        color: {
          default: theme.background.subtle,
          active: theme.background.weak,
          hover: theme.background.base,
          disable: theme.background.base
        }
      },
      text: {
        color: {
          default: theme.content.subtle,
          active: theme.content.base,
          hover: theme.content.base,
          disable: theme.contentState.base.disable
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          active: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      borderRadius: theme.borderRadius.none,
      fieldLabel: theme.desktop.label.secondary,
      outsideBorder: {
        color: {
          generic: _index.tokens.null['100']
        }
      }
    }
  },
  accordion: {
    icon: {
      size: '24px',
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    header: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.S,
      color: {
        default: _index.tokens.null['100'],
        hover: theme.background.subtle,
        disable: _index.tokens.null['100']
      }
    },
    content: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.M,
      gap: _index.tokens.padding.L,
      color: {
        default: _index.tokens.null['100'],
        hover: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        title: {
          default: theme.content.base,
          hover: theme.content.base,
          disable: theme.contentState.base.disable
        },
        content: {
          default: theme.content.subtle,
          hover: theme.content.subtle
        }
      }
    },
    border: {
      color: {
        default: theme.border.base,
        hover: theme.border.base,
        disable: theme.border.weak
      }
    },
    titleLabel: theme.desktop.label.secondary,
    contentLabel: theme.desktop.body.secondary
  },
  accordions: {
    borderRadius: theme.borderRadius.none
  },
  tile: {
    icon: {
      size: '24px',
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        selected: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    img: {
      sizeWidth: '80px',
      sizeHeight: '40px',
      opacity: '50%'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.M,
    gap: _index.tokens.padding.S,
    container: {
      color: {
        default: theme.background.base,
        hover: theme.background.base,
        selected: theme.background.base,
        disable: theme.background.base
      }
    },
    border: {
      color: {
        default: _index.tokens.null['100'],
        hover: theme.border.base,
        selected: theme.border.dark,
        disable: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        selected: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    textLabel: theme.mobile.body.tertiary
  },
  border: {
    borderRadius: theme.borderRadius.tiny
  },
  accordionGroup: {
    gap: _index.tokens.padding.NONE
  },
  inputNumber: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.base,
          disable: theme.contentState.weak.disable
        }
      }
    },
    fieldLabel: theme.desktop.input.secondary,
    required: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    error: theme.desktop.input.secondary,
    borderRadius: theme.borderRadius.none
  },
  rangeSlider: {
    gap: _index.tokens.padding.XS,
    lineAccent: {
      color: {
        default: theme.background.accent,
        disable: theme.backgroundState.darkLight.disable
      }
    },
    lineBackground: {
      color: {
        default: theme.background.darkLight,
        disable: theme.backgroundState.darkLight.disable
      }
    },
    knob: {
      color: {
        default: theme.background.base,
        active: theme.background.accent,
        disable: theme.backgroundState.dark.disable
      },
      border: {
        default: theme.border.darkLight,
        active: _index.tokens.null['100'],
        disable: _index.tokens.null['100']
      }
    },
    valueLabel: theme.desktop.body.tertiary,
    textLabel: {
      color: {
        default: theme.content.subtle,
        disable: theme.contentState.subtle.disable
      }
    }
  },
  topTagline: {
    paddingHorizontal: _index.tokens.padding.L,
    paddingVertical: _index.tokens.padding.M,
    container: {
      color: {
        default: theme.background.dark
      }
    },
    text: {
      color: {
        default: theme.content.baseInverse
      }
    },
    textLabel: theme.desktop.body.tertiary
  },
  textArea: {
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          error: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      }
    },
    borderRadius: theme.borderRadius.none,
    fieldLabel: theme.desktop.input.secondary,
    required: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    error: theme.desktop.input.secondary
  },
  sectionHeader: {
    safeZone: _index.tokens.padding.L,
    gap: _index.tokens.padding.M,
    container: {
      color: {
        default: theme.background.accent
      }
    },
    text: {
      color: {
        default: theme.content.base
      }
    },
    textLabel: theme.desktop.headings.h1
  },
  progressBar: {
    lineAccent: {
      color: {
        default: theme.background.accent,
        disable: theme.backgroundState.darkLight.disable
      }
    },
    lineBackground: {
      color: {
        default: theme.background.darkLight,
        disable: theme.backgroundState.darkLight.disable
      }
    },
    textLabel: {
      color: {
        default: theme.content.subtle,
        disable: theme.contentState.subtle.disable
      }
    },
    safeZone: _index.tokens.padding.L,
    gap: _index.tokens.padding.XS,
    valueLabel: theme.desktop.body.tertiary
  },
  topTaglogin: {
    paddingHorizontal: _index.tokens.padding.L,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    icon: {
      size: '18px',
      color: {
        default: theme.content.baseInverse
      }
    },
    container: {
      color: {
        default: theme.background.dark
      }
    },
    text: {
      color: {
        fieldLabel: {
          disable: theme.content.baseInverse
        }
      }
    },
    fieldLabel: theme.desktop.input.secondary
  },
  verticalCard: {
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          hover: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100'],
          disable: _index.tokens.null['100']
        }
      },
      title: {
        color: {
          default: theme.content.base,
          hover: theme.content.base
        }
      },
      description: {
        color: {
          default: theme.content.subtle,
          hover: theme.content.subtle
        }
      }
    },
    mobile: {
      pictogram: {
        size: '40px'
      },
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.XL,
      gap: _index.tokens.padding.M,
      title: theme.mobile.headings.h4,
      description: theme.mobile.body.tertiary
    },
    desktop: {
      pictogram: {
        size: '48px'
      },
      paddingHorizontal: _index.tokens.padding.XL,
      paddingVertical: _index.tokens.padding['2XL'],
      gap: _index.tokens.padding.L,
      title: theme.desktop.headings.h4,
      description: theme.desktop.body.tertiary
    },
    light: {
      container: {
        color: {
          default: theme.background.base,
          hover: theme.background.base
        },
        border: {
          default: _index.tokens.null['100'],
          hover: _index.tokens.null['100']
        }
      },
      title: {
        color: {
          default: theme.content.base,
          hover: theme.content.base
        }
      },
      description: {
        color: {
          default: theme.content.subtle,
          hover: theme.content.subtle
        }
      }
    },
    borderRadius: theme.borderRadius.none,
    shadow: {
      default: theme.shadow.lvl1,
      hover: theme.shadow.lvl5
    }
  },
  stepper: {
    icon: {
      size: '20px',
      completed: theme.content.accent,
      error: theme.content.danger
    },
    indicator: {
      gap: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.S
    },
    circle: {
      default: _index.tokens.null['100'],
      selected: _index.tokens.null['100'],
      completed: _index.tokens.null['100'],
      error: _index.tokens.null['100']
    },
    border: {
      default: theme.content.weak,
      selected: theme.content.base,
      completed: theme.content.accent,
      error: theme.content.danger
    },
    text: {
      default: theme.content.weak,
      selected: theme.content.base
    },
    textTitle: {
      fontWeight: _index.tokens.fontWeight.bold,
      lineHeight: _index.tokens.lineHeight['300'],
      fontSize: _index.tokens.fontSize['400'],
      letterSpacing: _index.tokens.letterSpacing.S
    },
    textIndicator: {
      fontWeight: _index.tokens.fontWeight.bold,
      lineHeight: _index.tokens.lineHeight['100'],
      fontSize: _index.tokens.fontSize['50'],
      letterSpacing: _index.tokens.letterSpacing.XL
    },
    lineStepper: {
      default: theme.content.weak
    },
    rowContent: {
      gap: _index.tokens.flexbox.M
    },
    content: {
      paddingBottom: _index.tokens.padding['3XL'],
      gap: _index.tokens.padding.L
    },
    wrapper: _index.tokens.padding.NONE
  },
  price: {
    text: {
      accent: theme.content.accent,
      base: theme.content.base,
      danger: theme.content.danger
    },
    mobile: {
      small: theme.mobile.label.primary,
      medium: theme.mobile.headings.h4
    },
    desktop: {
      small: theme.desktop.label.primary,
      medium: theme.desktop.headings.h4
    },
    gap: _index.tokens.padding.XXXS
  },
  testimonialCard: {
    paddingHorizontal: _index.tokens.padding['2XL'],
    paddingVertical: _index.tokens.padding['2XL'],
    gap: _index.tokens.padding.XL,
    container: {
      color: {
        default: theme.background.base
      }
    },
    text: {
      color: {
        userLocatioin: {
          default: theme.content.subtle
        },
        title: {
          default: theme.content.base
        },
        body: {
          default: theme.content.base
        },
        userName: {
          default: theme.content.subtle
        }
      }
    },
    desktop: {
      titleLabel: theme.desktop.headings.h4,
      bodyLabel: theme.desktop.body.secondary,
      userLabel: theme.desktop.label.primary,
      locationLabel: theme.desktop.input.primary
    },
    img: {
      sizeWidth: '60px',
      sizeHeight: '60px'
    },
    mobile: {
      titleLabel: theme.mobile.headings.h4,
      bodyLabel: theme.mobile.body.secondary,
      userLabel: theme.mobile.label.primary,
      locationLabel: theme.mobile.input.primary
    }
  },
  divider: {
    desktop: {
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.S,
      text: theme.desktop.body.tertiary
    },
    mobile: {
      paddingVertical: _index.tokens.padding.S,
      gap: _index.tokens.padding.XS,
      text: theme.mobile.body.tertiary
    },
    text: {
      default: theme.content.weak
    },
    border: {
      default: theme.border.base
    }
  },
  pagination: {
    gap: _index.tokens.padding.S,
    pages: {
      icon: {
        size: '24px',
        default: theme.content.subtle
      },
      typography: {
        color: {
          default: theme.content.subtle
        }
      },
      text: theme.desktop.input.primary
    }
  },
  rating: {
    icon: {
      size: '24x',
      color: {
        default: theme.content.accent
      }
    },
    gap: _index.tokens.padding.NONE
  },
  carousel: {
    gap: _index.tokens.padding.M,
    indicatorGap: _index.tokens.padding.L,
    indicator: {
      background: {
        active: theme.background.accent,
        default: theme.background.darkLight
      },
      gap: _index.tokens.padding.S
    }
  },
  sideMenu: {
    icon: {
      size: '20px'
    },
    gap: _index.tokens.padding.L,
    contentGap: _index.tokens.padding.L,
    textLabel: {
      color: {
        active: theme.content.base,
        default: theme.content.weak
      }
    },
    fieldLabel: theme.desktop.body.primary
  },
  chips: {
    icon: {
      size: '24px',
      sizeSmall: '18px',
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        selected: theme.content.base,
        disable: theme.contentState.base.disable
      }
    },
    media: {
      size: '24px'
    },
    medium: {
      paddingHorizontal: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.S,
      gap: _index.tokens.padding.S,
      textLabel: theme.desktop.label.secondary
    },
    small: {
      textLabel: theme.mobile.label.tertiary,
      paddingHorizontal: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.XS,
      gap: _index.tokens.padding.S
    },
    large: {
      paddingHorizontal: _index.tokens.padding.M,
      paddingVertical: _index.tokens.padding.M,
      gap: _index.tokens.padding.S,
      textLabel: theme.desktop.label.secondary
    },
    borderRadius: theme.borderRadius.none,
    container: {
      color: {
        default: theme.background.base,
        hover: theme.background.base,
        selected: theme.background.accentLight
      }
    },
    border: {
      color: {
        default: theme.border.base
      }
    },
    text: {
      color: {
        default: theme.content.base,
        hover: theme.content.base,
        selected: theme.content.base,
        disable: theme.contentState.base.disable
      }
    }
  },
  productCard: {
    carrier: {
      asset: {
        size: '48px'
      }
    },
    highlight: {
      icon: {
        size: '20px',
        color: {
          default: theme.content.baseInverse
        }
      },
      gap: _index.tokens.padding.S,
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.S,
      background: {
        color: {
          default: theme.background.dark
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          default: theme.content.baseInverse
        }
      },
      label: theme.desktop.body.tertiary
    },
    addOns: {
      icon: {
        size: '20px',
        color: {
          base: {
            default: theme.content.base,
            selected: theme.content.base
          },
          accent: {
            default: theme.content.accent,
            selected: theme.content.accent
          }
        }
      },
      text: {
        color: {
          coverageLabel: {
            default: theme.content.subtle,
            selected: theme.content.subtle
          }
        }
      },
      specialCoverages: {
        text: theme.desktop.label.secondary
      }
    },
    card: {
      gap: _index.tokens.padding.S,
      paddingHorizontal: _index.tokens.padding.XL,
      paddingVertical: _index.tokens.padding.XL,
      background: {
        color: {
          default: theme.background.base,
          selected: theme.background.base
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100'],
          selected: theme.border.dark
        }
      }
    },
    planInfo: {
      mobile: {
        gap: _index.tokens.padding.L
      },
      desktop: {
        gap: _index.tokens.padding['2XL']
      },
      mainInfo: {
        gap: _index.tokens.padding.L,
        priceGap: _index.tokens.padding.NONE,
        nameGap: _index.tokens.padding.NONE,
        contentGap: _index.tokens.padding.S
      },
      coverageSummary: {
        gap: _index.tokens.padding.S,
        contentGap: _index.tokens.padding.XL
      },
      compare: {
        gap: _index.tokens.padding.XS
      },
      addOns: {
        optional: {
          gap: _index.tokens.padding.S
        },
        special: {
          gap: _index.tokens.padding.L,
          contentGap: _index.tokens.padding.XS
        },
        itemGap: {
          desktop: _index.tokens.padding.NONE,
          mobile: _index.tokens.padding.L
        }
      },
      background: {
        color: {
          default: theme.background.base,
          selected: theme.background.base
        }
      },
      text: {
        color: {
          mainInfo: {
            productName: {
              default: theme.content.base,
              selected: theme.content.base
            },
            carrierName: {
              default: theme.content.subtle,
              selected: theme.content.subtle
            },
            duration: {
              default: theme.content.subtle,
              selected: theme.content.subtle
            }
          },
          coverageSummary: {
            coverage: {
              default: theme.content.subtle,
              selected: theme.content.subtle
            },
            price: {
              default: theme.content.base,
              selected: theme.content.base
            }
          },
          compare: {
            label: {
              default: theme.content.base,
              hover: theme.content.base,
              selected: theme.content.accent
            }
          }
        }
      }
    },
    coverageDetail: {
      icon: {
        size: '20px',
        color: {
          default: theme.content.danger,
          selected: theme.content.danger
        }
      },
      gap: _index.tokens.padding.S,
      contentGap: _index.tokens.padding.S,
      price: theme.desktop.label.secondary,
      coverage: theme.desktop.body.secondary,
      text: {
        color: {
          coverage: {
            default: theme.content.subtle,
            selected: theme.content.subtle
          },
          price: {
            default: theme.content.base,
            selected: theme.content.base
          },
          error: {
            default: theme.content.danger,
            selected: theme.content.danger
          }
        }
      }
    },
    coverageContainer: {
      gap: _index.tokens.padding.XL,
      rowGap: _index.tokens.padding['2XL'],
      paddingVertical: _index.tokens.padding.XL,
      paddingHorizontal: _index.tokens.padding.XL,
      background: {
        color: {
          default: theme.background.subtle,
          selected: theme.background.subtle
        }
      },
      text: {
        color: {
          title: {
            default: theme.content.base,
            selected: theme.content.base
          }
        }
      },
      title: theme.desktop.label.primary
    },
    actions: {
      gap: _index.tokens.padding.L
    },
    borderRadius: theme.borderRadius.none,
    shadow: {
      default: theme.shadow.lvl3,
      selected: theme.shadow.lvl3
    },
    mainInfo: {
      productName: theme.desktop.label.primary,
      carrierName: theme.desktop.body.tertiary,
      duration: theme.desktop.body.tertiary
    },
    coverageSummary: {
      price: theme.desktop.label.secondary,
      coverage: theme.desktop.body.secondary
    },
    compare: {
      label: theme.desktop.body.tertiary
    },
    wrapper: {
      gap: _index.tokens.padding.NONE
    }
  },
  descriptionWrapper: {
    icon: {
      small: {
        size: '20px'
      },
      large: {
        size: '32px'
      },
      color: {
        default: theme.content.danger,
        included: theme.content.base
      }
    },
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.S,
    small: {
      placeholder: theme.desktop.label.secondary,
      label: theme.desktop.body.secondary
    },
    text: {
      color: {
        label: {
          default: theme.content.subtle
        },
        placeholder: {
          default: theme.content.base,
          error: theme.content.danger
        }
      }
    },
    large: {
      paddingVertical: _index.tokens.padding.L,
      borderRadius: theme.borderRadius.tiny,
      placeholder: theme.desktop.headings.h1Light,
      label: theme.desktop.headings.h4
    },
    container: {
      border: theme.border.base
    }
  },
  collapse: {
    pictogram: {
      size: '32px',
      color: {
        main: theme.content.base,
        accent: theme.content.accent
      }
    },
    icon: {
      size: '28px',
      color: {
        default: theme.content.base,
        error: theme.content.danger,
        success: theme.content.accent
      }
    },
    desktop: {
      paddingHorizontal: _index.tokens.padding.XL,
      paddingVertical: _index.tokens.padding.XL,
      gap: _index.tokens.padding.L,
      header: {
        gap: _index.tokens.padding.L,
        paddingVertical: _index.tokens.padding.XL
      },
      label: theme.desktop.headings.h4
    },
    mobile: {
      paddingHorizontal: _index.tokens.padding.XL,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.L,
      header: {
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.L
      },
      label: theme.mobile.headings.h4
    },
    borderRadius: theme.borderRadius.none,
    default: theme.shadow.lvl2,
    selected: theme.shadow.lvl0,
    container: {
      color: {
        default: theme.content.baseInverse
      }
    },
    border: {
      color: {
        default: theme.content.baseInverse,
        error: theme.border.danger,
        focus: theme.border.dark,
        success: theme.border.focus
      }
    },
    label: {
      color: {
        default: theme.content.base
      }
    },
    borderDivider: {
      color: {
        default: theme.border.base
      }
    }
  },
  collapseGroup: {
    desktop: {
      gap: _index.tokens.padding.XL
    },
    mobile: {
      gap: _index.tokens.padding.L
    }
  },
  breadcrumb: {
    icon: {
      size: '18px',
      color: {
        default: theme.content.subtle
      }
    },
    gap: _index.tokens.padding.S,
    cotentGap: _index.tokens.padding.S,
    label: {
      inactive: {
        color: {
          default: theme.content.subtle
        }
      },
      active: {
        color: {
          default: theme.content.base
        }
      }
    },
    textLabel: {
      color: {
        default: theme.content.subtle,
        current: theme.content.base
      }
    }
  },
  tooltip: {
    short: {
      paddingHorizontal: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.XS
    },
    long: {
      paddingHorizontal: _index.tokens.padding.M,
      paddingVertical: _index.tokens.padding.S
    },
    label: theme.desktop.input.secondary,
    shadow: theme.shadow.lvl3,
    borderRadius: theme.borderRadius.tiny,
    background: {
      color: {
        light: theme.background.base,
        grey: theme.background.weak,
        dark: theme.background.dark
      }
    },
    text: {
      color: {
        light: theme.content.base,
        grey: theme.content.base,
        dark: theme.content.baseInverse
      }
    }
  },
  spinner: {
    gap: _index.tokens.padding.XS,
    background: {
      color: {
        dark: theme.background.dark,
        light: theme.background.weak
      }
    }
  },
  loadingHorizontal: {
    gap: _index.tokens.padding.XS,
    background: {
      color: {
        dark: theme.background.dark,
        light: theme.background.weak
      }
    },
    dark: {
      rectangle: {
        1: '18px',
        2: '14px',
        3: '10px'
      }
    },
    light: {
      rectangle: {
        1: '18px',
        2: '14px',
        3: '10px'
      }
    },
    'rectangle 1': {
      borderRadius: theme.borderRadius.none
    },
    'rectangle 2': {
      borderRadius: theme.borderRadius.none
    },
    'rectangle 3': {
      borderRadius: theme.borderRadius.none
    }
  },
  loadingMessage: {
    text: {
      color: {
        title: {
          dark: theme.content.base,
          light: theme.content.baseInverse
        },
        contentText: {
          dark: theme.content.subtle,
          light: theme.content.subtleInverse
        }
      },
      gap: _index.tokens.padding.XS
    },
    title: theme.desktop.label.primary,
    contentText: theme.desktop.body.secondary,
    gap: _index.tokens.padding.XS
  },
  spinnerBox: {
    background: {
      color: {
        dark: theme.background.dark,
        light: theme.background.weak
      }
    }
  },
  footer: {
    desktop: {
      rightsReserved: theme.desktop.body.tertiary,
      poweredBy: theme.desktop.label.tertiary,
      stack: {
        title: theme.desktop.body.secondary,
        subtitle: theme.desktop.body.primary,
        gap: _index.tokens.padding.S
      },
      wrapper: {
        gap: {
          default: _index.tokens.padding['2XL']
        }
      },
      links: {
        gap: {
          default: _index.tokens.padding['2XL']
        }
      },
      paddingHorizontal: _index.tokens.flexbox['2XL'],
      paddingVertical: _index.tokens.padding['4XL'],
      carrier: {
        gap: _index.tokens.padding.S
      },
      options: {
        gap: _index.tokens.padding.L
      }
    },
    mobile: {
      rightsReserved: theme.mobile.input.secondary,
      poweredBy: theme.mobile.label.tertiary,
      stack: {
        title: theme.mobile.body.secondary,
        subtitle: theme.mobile.body.primary,
        gap: _index.tokens.padding.S
      },
      wrapper: {
        gap: {
          default: _index.tokens.padding.L
        }
      },
      links: {
        gap: {
          default: _index.tokens.padding.NONE
        }
      },
      options: {
        gap: {
          default: _index.tokens.padding.L
        }
      },
      coutainer: {
        gap: {
          default: _index.tokens.padding.XL
        }
      },
      paddingHorizontal: _index.tokens.padding['2XL'],
      paddingVertical: _index.tokens.padding['2XL'],
      carrier: {
        gap: _index.tokens.padding.S,
        textStyle: {
          default: theme.desktop.label.tertiary
        }
      }
    },
    background: {
      color: {
        default: theme.background.dark
      }
    },
    button: {
      color: {
        default: theme.background.base
      }
    },
    poweredBy: {
      color: {
        default: theme.content.baseInverse
      }
    },
    allRightsReserved: {
      color: {
        default: theme.content.subtleInverse
      }
    },
    stack: {
      title: {
        color: {
          default: theme.content.weak
        }
      },
      subtitle: {
        color: {
          default: theme.content.baseInverse
        }
      }
    }
  },
  header: {
    paddingHorizontal: _index.tokens.flexbox['2XL'],
    paddingVertical: _index.tokens.padding.L,
    leftContent: {
      gap: _index.tokens.flexbox.M
    },
    headerMenu: {
      textLinks: {
        gap: _index.tokens.flexbox.M,
        bottom: {
          padding: _index.tokens.padding.XS
        }
      },
      rightContent: {
        gap: _index.tokens.flexbox.S,
        icons: {
          gap: _index.tokens.flexbox.XS
        },
        langSelector: {
          gap: _index.tokens.padding.S
        },
        icon: '24px'
      }
    },
    container: {
      gap: _index.tokens.flexbox['2XL']
    },
    typography: {
      text: {
        color: {
          default: theme.contentState.weak.active,
          active: theme.content.base
        },
        border: {
          default: _index.tokens.null['100'],
          active: theme.content.subtleInverse
        }
      }
    },
    rightContent: {
      langSelector: {
        text: {
          color: {
            default: theme.content.base
          }
        },
        line: {
          color: {
            default: theme.content.base
          }
        },
        generic: {
          textLabel: {
            fontWeight: _index.tokens.fontWeight.bold,
            lineHeight: _index.tokens.lineHeight['200'],
            fontSize: _index.tokens.fontSize['100'],
            letterSpacing: _index.tokens.letterSpacing.XL
          }
        }
      }
    },
    textLinks: {
      generic: {
        textLabel: {
          default: theme.mobile.input.primary,
          selected: theme.mobile.button.secondary
        }
      }
    },
    wrapper: {
      background: {
        color: {
          default: theme.content.baseInverse
        }
      },
      border: {
        color: {
          default: theme.content.subtleInverse
        }
      }
    },
    mobile: {
      paddingHorizontal: _index.tokens.padding['2XL'],
      paddingVertical: _index.tokens.padding.S,
      wrapper: {
        background: {
          color: theme.content.baseInverse
        },
        border: {
          color: {
            default: theme.content.subtleInverse
          }
        }
      },
      burguerMenu: {
        color: theme.content.base
      }
    }
  },
  avatar: {
    container: {
      image: {
        size: '100px'
      },
      icon: {
        size: '90px'
      },
      radius: theme.borderRadius.elipse
    },
    gap: _index.tokens.padding.L,
    typography: {
      color: {
        text: {
          default: theme.content.base
        }
      },
      name: {
        default: {
          fontWeight: _index.tokens.fontWeight.light,
          lineHeight: _index.tokens.lineHeight['200'],
          fontSize: _index.tokens.fontSize['100'],
          letterSpacing: _index.tokens.letterSpacing.XL
        }
      }
    }
  },
  modal: {
    titleHeader: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.L,
      icon: {
        color: {
          default: theme.content.base
        },
        size: '32px'
      },
      typography: {
        color: {
          default: theme.content.base
        },
        default: {
          fontWeight: _index.tokens.fontWeight.light,
          lineHeight: _index.tokens.lineHeight['300'],
          fontSize: _index.tokens.fontSize['300'],
          letterSpacing: _index.tokens.letterSpacing.M
        }
      }
    },
    content: {
      paddingHorizontal: _index.tokens.padding.XL,
      paddingVertical: _index.tokens.padding.XL,
      border: {
        color: {
          default: theme.border.subtle
        }
      }
    },
    wrapperButtons: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.XL
    },
    background: {
      color: {
        default: theme.content.baseInverse
      }
    },
    shadow: theme.shadow.lvl3
  },
  tag: {
    background: {
      color: {
        darkLight: theme.background.darkLight,
        warning: theme.background.warningLight,
        dangerLight: theme.background.dangerLight,
        accentLight: theme.background.accentLight,
        successLight: theme.background.successLight,
        null: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        default: theme.content.base
      }
    },
    paddingHorizontal: _index.tokens.padding.S,
    paddingVertical: _index.tokens.padding.XXS,
    textLabel: {
      default: theme.desktop.input.secondary,
      bold: theme.desktop.label.tertiary
    },
    table: {
      labelRowTable: {
        icon: {
          size: '24px'
        },
        text: {
          paddingVertical: _index.tokens.padding.XXS
        }
      }
    }
  },
  summaryCard: {
    titleWrapper: {
      icon: {
        size: '44px'
      },
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.S,
      header: {
        fontWeight: _index.tokens.fontWeight.bold,
        lineHeight: _index.tokens.lineHeight['200'],
        fontSize: _index.tokens.fontSize['125'],
        letterSpacing: _index.tokens.letterSpacing.XL,
        paragraphSpacing: _index.tokens.paragraphSpacing.none,
        color: {
          default: theme.content.base
        }
      },
      fieldLabel: {
        color: {
          default: theme.content.base
        }
      }
    },
    planDetailsWrapper: {
      paddingVertical: _index.tokens.padding.L,
      paddingHorizontal: _index.tokens.padding.L,
      fieldLabel: {
        default: {
          fontWeight: _index.tokens.fontWeight.bold,
          lineHeight: _index.tokens.lineHeight['200'],
          fontSize: _index.tokens.fontSize['100'],
          letterSpacing: _index.tokens.letterSpacing.XL,
          paragraphSpacing: _index.tokens.paragraphSpacing.none
        },
        color: {
          default: theme.content.base
        }
      },
      coverageSummary: {
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.L
      }
    },
    priceWrapper: {
      paddingHorizontal: _index.tokens.padding.L,
      totalPriceLabel: {
        gap: _index.tokens.flexbox.XXS,
        finalPrice: {
          color: {
            default: theme.content.base
          }
        },
        timeSet: {
          color: {
            default: theme.content.base
          }
        }
      },
      fieldLabel: {
        color: {
          default: theme.content.base
        }
      }
    },
    priceDetailsWrapper: {
      fieldLabel: {
        default: {
          fontWeight: _index.tokens.fontWeight.bold,
          lineHeight: _index.tokens.lineHeight['200'],
          fontSize: _index.tokens.fontSize['100'],
          letterSpacing: _index.tokens.letterSpacing.XL,
          paragraphSpacing: _index.tokens.paragraphSpacing.none
        }
      },
      totalPriceLabel: {
        default: {
          fontWeight: _index.tokens.fontWeight.bold,
          lineHeight: _index.tokens.lineHeight['200'],
          fontSize: _index.tokens.fontSize['100'],
          letterSpacing: _index.tokens.letterSpacing.XL,
          paragraphSpacing: _index.tokens.paragraphSpacing.none
        },
        timeSet: {
          fontWeight: _index.tokens.fontWeight.regular,
          lineHeight: _index.tokens.lineHeight['150'],
          fontSize: _index.tokens.fontSize['75'],
          letterSpacing: _index.tokens.letterSpacing.XL,
          paragraphSpacing: _index.tokens.paragraphSpacing.none
        }
      }
    },
    actionWrapper: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.padding.L,
      legalText: {
        label: {
          color: {
            default: theme.content.base
          }
        }
      },
      loyalityText: {
        default: theme.desktop.input.secondary
      }
    },
    container: {
      color: {
        default: theme.content.baseInverse
      }
    },
    shadow: theme.shadow.lvl2
  },
  successCard: {
    shadow: theme.shadow.lvl2,
    headerCard: {
      carrier: {
        asset: {
          size: '28px'
        }
      },
      paddingVertical: _index.tokens.padding.XL,
      paddingHorizontal: _index.tokens.padding.XL,
      gap: _index.tokens.padding.S,
      text: {
        color: {
          default: theme.content.base
        }
      }
    },
    cardInfo: {
      carrier: {
        asset: {
          size: '42px'
        }
      },
      paddingVertical: _index.tokens.padding.XL,
      paddingHorizontal: _index.tokens.padding.XL,
      gap: _index.tokens.padding.L,
      planInfo: {
        gap: _index.tokens.padding.L
      },
      productName: {
        text: {
          default: theme.content.base
        }
      },
      carrierName: {
        text: {
          default: theme.content.subtle
        }
      },
      text: {
        productName: {
          default: theme.desktop.label.primary
        },
        carrierName: {
          default: theme.desktop.body.tertiary
        }
      },
      rowCoverage: {
        gap: _index.tokens.padding.L
      }
    },
    summary: {
      icon: {
        size: '20px',
        color: {
          default: theme.content.accent
        }
      },
      paddingVertical: _index.tokens.padding.XL,
      paddingHorizontal: _index.tokens.padding.XL,
      gap: _index.tokens.padding.XL,
      special: {
        itemGap: {
          gap: _index.tokens.padding.XS
        },
        gap: _index.tokens.padding.L
      },
      text: {
        color: {
          default: theme.content.subtle
        },
        default: theme.desktop.label.secondary
      }
    },
    background: {
      default: theme.background.base
    },
    header: {
      text: {
        default: theme.desktop.headings.h4
      }
    }
  },
  sidePanel: {
    countainer: {
      shadow: theme.shadow.lvl2
    },
    desktop: {
      countainer: {
        paddingHorizontalLeft: _index.tokens.padding['2XL'],
        paddingHorizontalRight: _index.tokens.flexbox['2XL'],
        paddingVerticalBottom: _index.tokens.padding['2XL'],
        paddingVerticalTop: _index.tokens.padding.L,
        gap: _index.tokens.padding.L,
        background: {
          color: {
            default: theme.background.base
          }
        },
        border: {
          color: {
            default: theme.borderState.dark.disable
          }
        }
      }
    },
    mobile: {
      paddingHorizontalLeft: _index.tokens.padding.XL,
      countainer: {
        paddingHorizontalLeft: _index.tokens.padding.XL,
        gap: _index.tokens.padding.S,
        paddingVerticalTop: _index.tokens.padding.M,
        paddingVerticalBottom: _index.tokens.padding['2XL'],
        paddingHorizontalRight: _index.tokens.padding.L,
        background: {
          color: {
            default: theme.background.base
          }
        },
        border: {
          color: {
            default: theme.border.darkLight
          }
        }
      },
      background: {
        color: {
          default: _index.tokens.null['100']
        }
      }
    }
  },
  calendar: {
    day: {
      typography: {
        color: {
          default: theme.content.base,
          otherMonth: theme.content.weak,
          disabled: theme.content.subtleInverse
        }
      },
      textLabel: theme.desktop.body.secondary,
      background: {
        color: {
          default: _index.tokens.null['100'],
          hover: theme.background.accent
        }
      },
      border: {
        color: {
          default: _index.tokens.null['100'],
          today: theme.content.base
        }
      },
      paddingHorizontal: _index.tokens.padding.M,
      paddingVertical: _index.tokens.padding.M
    },
    header: {
      paddingHorizontal: _index.tokens.padding.L,
      paddingVertical: _index.tokens.padding.L,
      gap: _index.tokens.flexbox.XXS,
      background: {
        color: {
          default: theme.background.weak
        }
      },
      textLabel: theme.desktop.body.primary,
      text: {
        color: {
          default: theme.content.base
        }
      },
      icon: {
        size: '24px',
        color: {
          default: theme.content.base
        }
      }
    },
    weeks: {
      paddingHorizontal: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.S,
      background: {
        color: {
          default: theme.backgroundState.base.disable
        }
      }
    },
    container: {
      shadow: theme.shadow.lvl2
    },
    buttons: {
      paddingVertical: _index.tokens.padding.S,
      gap: _index.tokens.flexbox.S,
      paddingHorizontal: _index.tokens.padding.XL,
      border: {
        color: {
          default: theme.content.subtleInverse
        }
      }
    }
  },
  notification: {
    paddingVertical: _index.tokens.padding.S,
    paddingHorizontal: _index.tokens.padding.S,
    background: {
      color: {
        default: theme.background.darkLight,
        warning: theme.background.warningLight,
        error: theme.background.dangerLight,
        success: theme.background.successLight,
        accent: theme.background.accentLight,
        null: _index.tokens.null['100']
      }
    },
    text: {
      color: {
        default: theme.content.base
      }
    },
    icon: {
      size: '20px',
      color: {
        default: theme.content.base
      }
    },
    textLabel: theme.desktop.body.secondary,
    gap: _index.tokens.flexbox.XXS
  },
  search: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.M,
    gap: _index.tokens.padding.XS,
    borderRadius: theme.borderRadius.none,
    grey: {
      textLabel: theme.desktop.input.primary,
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            disable: theme.contentState.weak.disable
          }
        }
      },
      icon: {
        color: {
          default: theme.content.weak,
          filled: theme.content.weak,
          focus: theme.content.weak,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      textLabel: theme.desktop.input.primary,
      container: {
        color: {
          default: theme.backgroundState.base.disable,
          filled: theme.backgroundState.base.disable,
          focus: theme.backgroundState.base.disable,
          disable: theme.backgroundState.base.disable
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            disable: theme.contentState.weak.disable
          }
        }
      },
      icon: {
        color: {
          default: theme.content.weak,
          filled: theme.content.weak,
          focus: theme.content.weak,
          disable: theme.contentState.weak.disable
        }
      }
    }
  },
  calendarPicker: {
    icon: {
      size: '20px'
    },
    paddingHorizontal: _index.tokens.padding.M,
    paddingVertical: _index.tokens.padding.S,
    gap: _index.tokens.padding.S,
    contentGap: _index.tokens.padding.XS,
    requiredGap: _index.tokens.padding.XXXS,
    grey: {
      container: {
        color: {
          default: theme.background.weak,
          filled: theme.background.weak,
          focus: theme.background.weak,
          error: theme.background.weak,
          errorFilled: theme.background.weak,
          disable: theme.background.weak
        },
        border: {
          default: _index.tokens.null['100'],
          filled: _index.tokens.null['100'],
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: _index.tokens.null['100']
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    border: {
      container: {
        color: {
          default: theme.background.base,
          filled: theme.background.base,
          focus: theme.background.base,
          error: theme.background.base,
          errorFilled: theme.background.base,
          disable: theme.background.base
        },
        border: {
          default: theme.border.subtle,
          filled: theme.border.subtle,
          focus: theme.border.focus,
          error: theme.border.danger,
          errorFilled: theme.border.danger,
          disable: theme.border.subtle
        }
      },
      text: {
        color: {
          fieldLabel: {
            default: theme.content.base,
            filled: theme.content.weak,
            focus: theme.content.weak,
            error: theme.content.weak,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          inputPlaceholder: {
            default: theme.content.weak,
            filled: theme.content.base,
            focus: theme.content.base,
            error: theme.content.base,
            errorFilled: theme.content.base,
            disable: theme.contentState.weak.disable
          },
          required: {
            default: theme.content.danger,
            filled: theme.content.danger,
            focus: theme.content.danger,
            error: theme.content.danger,
            errorFilled: theme.content.danger,
            disable: theme.contentState.weak.disable
          },
          errorMessage: {
            error: theme.content.danger,
            errorFilled: theme.content.danger
          }
        }
      },
      icon: {
        color: {
          default: theme.content.accent,
          filled: theme.content.accent,
          focus: theme.content.accent,
          error: theme.content.danger,
          errorFilled: theme.content.danger,
          disable: theme.contentState.weak.disable
        }
      }
    },
    borderRadius: theme.borderRadius.none,
    fieldLabel: theme.desktop.input.secondary,
    required: theme.desktop.input.secondary,
    inputPlaceholder: theme.desktop.input.primary,
    error: theme.desktop.input.secondary
  },
  compare: {
    productSelectionClose: {
      select: {
        desktop: {
          icon: {
            size: '20px'
          },
          image: {
            size: '40px'
          },
          header: {
            paddingVertical: _index.tokens.padding.S,
            paddingHorizontal: _index.tokens.padding.S,
            icon: {
              color: theme.content.base
            }
          },
          productName: {
            gap: _index.tokens.padding.S,
            paddingHorizontal: _index.tokens.padding.L,
            paddingVertical: _index.tokens.padding.L,
            textLabel: {
              color: theme.content.base
            }
          },
          countainer: {
            background: {
              color: {
                selected: theme.content.baseInverse
              }
            },
            border: {
              color: {
                selected: theme.border.base
              }
            }
          }
        },
        mobile: {
          icon: {
            size: '16px'
          },
          image: {
            size: '24px'
          },
          header: {
            paddingVertical: _index.tokens.padding.S,
            paddingHorizontal: _index.tokens.padding.S,
            icon: {
              color: theme.content.base
            }
          },
          productName: {
            gap: _index.tokens.padding.S,
            paddingHorizontal: _index.tokens.padding.S,
            paddingVertical: _index.tokens.padding.S,
            textLabel: {
              color: theme.content.base
            }
          },
          countainer: {
            background: {
              color: {
                selected: theme.content.baseInverse
              }
            },
            border: {
              color: {
                selected: theme.border.base
              }
            }
          }
        }
      },
      default: {
        desktop: {
          image: {
            size: '68px'
          },
          paddingVertical: _index.tokens.padding.XL,
          paddingHorizontal: _index.tokens.padding.XL,
          countainer: {
            background: {
              color: {
                selected: theme.background.darkLight
              }
            },
            border: {
              color: {
                selected: theme.border.base
              }
            }
          }
        },
        mobile: {
          image: {
            size: '48px'
          },
          paddingVertical: _index.tokens.padding.S,
          paddingHorizontal: _index.tokens.padding.S,
          countainer: {
            background: {
              color: {
                selected: theme.background.darkLight
              }
            },
            border: {
              color: {
                selected: theme.border.base
              }
            }
          }
        }
      },
      desktop: {
        productName: {
          text: {
            default: theme.desktop.input.primary
          }
        }
      },
      mobile: {
        productName: {
          text: {
            default: theme.mobile.input.secondary
          }
        }
      },
      padding_none: _index.tokens.padding.NONE
    },
    coverageCompare: {
      icon: {
        size: '20px',
        color: {
          included: theme.content.base,
          notIncluded: theme.content.danger
        }
      },
      gap: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.XS,
      paddingHorizontal: _index.tokens.padding.XS,
      text: {
        color: {
          included: theme.content.base
        }
      },
      label: {
        default: theme.desktop.label.secondary
      }
    },
    productSelectionOpen: {
      gap: _index.tokens.padding.M,
      paddingHorizontal: _index.tokens.padding.S,
      paddingVertical: _index.tokens.padding.S,
      productName: {
        textLabel: {
          color: theme.content.base
        },
        text: {
          default: theme.desktop.input.secondary
        }
      },
      countainer: {
        background: {
          color: {
            selected: theme.content.baseInverse
          }
        },
        border: {
          color: {
            selected: theme.border.base
          }
        }
      }
    },
    openRows: {
      mobile: {
        gap: _index.tokens.padding.L,
        paddingVertical: _index.tokens.padding.S,
        paddingHorizontal: _index.tokens.padding.S,
        rowCoverage: {
          gap: {
            gap: _index.tokens.padding.L
          }
        },
        headerRow: {
          text: {
            default: theme.mobile.body.secondary
          }
        }
      },
      desktop: {
        gap: _index.tokens.padding.XL,
        paddingVertical: _index.tokens.padding.L,
        paddingHorizontal: _index.tokens.padding.XL,
        rowCoverage: {
          gap: {
            gap: _index.tokens.padding.XL
          }
        },
        headerRow: {
          text: {
            default: theme.desktop.body.primary
          }
        }
      },
      headerRow: {
        color: theme.content.subtle
      },
      border: {
        color: {
          selected: theme.border.base
        }
      }
    },
    close: {
      desktop: {
        topHeader: {
          icon: {
            size: '24px',
            color: {
              default: theme.content.base
            }
          },
          gap: _index.tokens.padding.L,
          paddingVertical: _index.tokens.padding.M,
          paddingHorizontal: _index.tokens.padding.M,
          background: {
            color: {
              default: theme.background.transaction
            }
          },
          text: {
            color: {
              default: theme.content.base
            },
            default: theme.desktop.button.secondary
          }
        },
        rowProductSelection: {
          actions: {
            gap: _index.tokens.padding.L,
            paddingVertical: _index.tokens.padding.L,
            paddingHorizontal: _index.tokens.padding.L
          },
          gap: _index.tokens.padding.XL,
          paddingVertical: _index.tokens.padding.XL,
          paddingHorizontal: _index.tokens.padding.XL
        },
        rowPlans: {
          background: {
            color: {
              default: theme.background.base
            }
          }
        }
      },
      mobile: {
        topHeader: {
          icon: {
            size: '24px',
            color: {
              default: theme.content.base
            }
          },
          gap: _index.tokens.padding.L,
          paddingVertical: _index.tokens.padding.M,
          paddingHorizontal: _index.tokens.padding.M,
          background: {
            color: {
              default: theme.background.transaction
            }
          },
          text: {
            color: {
              default: theme.content.base
            },
            default: theme.mobile.button.secondary
          }
        },
        rowProductSelection: {
          actions: {
            gap: _index.tokens.padding.L,
            paddingVertical: _index.tokens.padding.L,
            paddingHorizontal: _index.tokens.padding.L
          },
          gap: _index.tokens.padding.S,
          paddingVertical: _index.tokens.padding.L,
          paddingHorizontal: _index.tokens.padding.S
        },
        rowPlans: {
          background: {
            color: {
              default: theme.background.base
            }
          }
        },
        actions: {
          background: {
            color: {
              default: theme.background.base
            }
          },
          border: {
            color: {
              default: theme.borderState.dark.disable
            }
          }
        }
      }
    },
    productSelectionCompare: {
      shadow: {
        selected: theme.shadow.lvl2,
        default: theme.shadow.lvl0
      }
    },
    open: {
      desktop: {
        wrapper: {
          topHeader: {
            gap: _index.tokens.padding.S,
            paddingVertical: _index.tokens.padding.L,
            paddingHorizontal: _index.tokens.padding.XL,
            rowProducts: {
              gap: _index.tokens.padding.XL
            }
          },
          paddingVertical: _index.tokens.padding.L,
          titleCategories: {
            paddingVertical: _index.tokens.padding.L,
            paddingHorizontal: _index.tokens.padding.L
          }
        },
        titleCategories: {
          text: {
            default: theme.desktop.headings.h4
          }
        },
        topHeader: {
          background: {
            color: {
              default: theme.background.accentLight
            }
          }
        },
        rowPlans: {
          background: {
            color: {
              default: theme.background.base
            }
          },
          titleSection: {
            text: {
              color: {
                default: theme.contentState.weak.active
              }
            }
          }
        }
      },
      mobile: {
        wrapper: {
          topHeader: {
            gap: _index.tokens.padding.S,
            paddingVertical: _index.tokens.padding.S,
            paddingHorizontal: _index.tokens.padding.S,
            rowProducts: {
              gap: _index.tokens.padding.L
            }
          },
          paddingVertical: _index.tokens.padding.L,
          titleCategories: {
            paddingVertical: _index.tokens.padding.L,
            paddingHorizontal: _index.tokens.padding.S
          }
        },
        titleCategories: {
          text: {
            default: theme.mobile.headings.h4
          }
        },
        topHeader: {
          background: {
            color: {
              default: theme.background.accentLight
            }
          }
        },
        rowPlans: {
          background: {
            color: {
              default: theme.background.base
            }
          },
          titleSection: {
            text: {
              color: {
                default: theme.contentState.weak.active
              }
            }
          }
        }
      }
    },
    EmptySvg: {
      icon: {
        color: theme.content.subtle
      }
    }
  },
  icon: {
    color: {
      navy: theme.content.base
    }
  },
  filters: {
    desktop: {
      countainer: {
        paddingHorizontalLeft: _index.tokens.padding.XL,
        paddingHorizontalRight: _index.tokens.padding.NONE,
        paddingVertical: _index.tokens.padding.M,
        gap: _index.tokens.padding.S,
        background: {
          color: {
            default: theme.background.base
          }
        }
      },
      header: {
        paddingHorizontal: _index.tokens.padding.XL,
        paddingVertical: _index.tokens.padding.S,
        gap: _index.tokens.padding.S,
        borderLine: {
          color: {
            default: theme.borderState.darkLight.disable
          }
        },
        title: {
          text: {
            color: {
              default: theme.content.base
            }
          }
        },
        text: {
          default: theme.mobile.headings.h4
        }
      },
      filtersApplied: {
        paddingHorizontal: _index.tokens.padding.XL,
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.S,
        rowChips: {
          gap: {
            gap: _index.tokens.padding.S
          }
        },
        borderLine: {
          color: {
            default: theme.borderState.darkLight.disable
          }
        },
        title: {
          text: {
            color: {
              default: theme.content.base
            }
          }
        },
        text: {
          default: theme.desktop.label.secondary
        }
      },
      actions: {
        paddingHorizontal: _index.tokens.padding.XL,
        gap: _index.tokens.padding.L
      }
    },
    mobile: {
      countainer: {
        paddingHorizontalLeft: _index.tokens.padding.XL,
        paddingHorizontalRight: _index.tokens.padding.M,
        paddingVerticalTop: _index.tokens.padding.M,
        paddingVerticalBottom: _index.tokens.padding['2XL'],
        gap: _index.tokens.padding.L,
        background: {
          color: {
            default: theme.background.base
          }
        },
        border: {
          color: {
            default: theme.border.darkLight
          }
        }
      },
      filtersApplied: {
        paddingVertical: _index.tokens.padding.L,
        gap: _index.tokens.padding.S,
        rowChips: {
          gap: {
            gap: _index.tokens.padding.S
          }
        },
        borderLine: {
          color: {
            default: theme.borderState.darkLight.disable
          }
        },
        title: {
          text: {
            color: {
              default: theme.content.base
            }
          }
        },
        text: {
          default: theme.mobile.button.secondary
        }
      },
      actions: {
        gap: _index.tokens.padding.L
      },
      horizontalPadding: _index.tokens.padding.XL,
      background: {
        color: {
          default: _index.tokens.null['100']
        }
      },
      filtersResult: {
        title: {
          text: {
            color: {
              default: theme.content.base
            }
          }
        },
        text: {
          default: theme.mobile.button.secondary
        }
      },
      shadow: theme.shadow.lvl2
    }
  },
  loadingSpinner: {
    dark: {
      rectangle: {
        1: '34px',
        2: '34px'
      }
    },
    light: {
      rectangle: {
        1: '34px',
        2: '34px'
      }
    },
    background: {
      color: {
        dark: theme.background.dark,
        light: theme.background.weak
      }
    },
    'rectangle 1': {
      borderRadius: theme.borderRadius.none
    },
    'rectangle 2': {
      borderRadius: theme.borderRadius.none
    }
  },
  toggle: {
    on: {
      hover: {
        track: {
          active: theme.backgroundState.dark.active
        },
        handle: {
          active: theme.background.base
        },
        stateLayer: {
          active: theme.backgroundState.dark.active,
          opacity: '12%'
        },
        icon: {
          active: theme.backgroundState.dark.active
        }
      },
      disabled: {
        track: {
          active: theme.background.darkLight
        },
        handle: {
          active: theme.background.base
        },
        icon: {
          active: theme.background.darkLight
        }
      },
      selected: {
        track: {
          active: theme.backgroundState.dark.active
        },
        handle: {
          active: theme.background.base
        },
        icon: {
          active: theme.backgroundState.dark.active
        }
      },
      handle: {
        size: '24px'
      },
      stateLayer: {
        size: '40px'
      },
      icon: {
        size: '16px'
      }
    },
    off: {
      selected: {
        track: {
          border: theme.contentState.baseInverse.disable,
          background: theme.background.weak
        },
        handle: {
          active: theme.contentState.baseInverse.disable
        },
        icon: {
          active: theme.backgroundState.base.disable
        }
      },
      hover: {
        track: {
          border: theme.contentState.baseInverse.disable,
          background: theme.background.weak
        },
        handle: {
          active: theme.content.subtle
        },
        icon: {
          active: theme.backgroundState.base.disable
        },
        stateLayer: {
          active: theme.contentState.baseInverse.disable,
          opacity: '12%'
        }
      },
      disabled: {
        track: {
          border: theme.background.darkLight,
          background: theme.background.base
        },
        handle: {
          active: theme.contentState.weak.disable
        },
        icon: {
          active: theme.backgroundState.base.disable
        }
      },
      handleIconOff: {
        size: '16px'
      },
      stateLayer: {
        size: '40px'
      },
      handleIconOn: {
        size: '24px'
      },
      icon: {
        size: '16px'
      }
    },
    track: {
      borderRadius: theme.borderRadius.elipse
    }
  }
};
exports.components = components;