"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateThemeTemplate = exports.generateThemeIndexFile = void 0;
var _prettier = _interopRequireDefault(require("prettier"));
var _prettierrc = _interopRequireDefault(require("../../../.prettierrc.json"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const prettierConfig = {
  ..._prettierrc.default,
  parser: 'babel'
};
const replaceWordsMap = {
  boxShadow: 'shadow',
  'ref.': 'tokens.',
  'sys.': 'theme.'
};
const formatObject = tokenObject => {
  const regex = new RegExp(Object.keys(replaceWordsMap).join('|'), 'gi');
  return tokenObject.replaceAll(regex, matched => {
    return replaceWordsMap[matched];
  }).replaceAll(/\.color|\.typography/gi, '').replaceAll(/\.[0-9]+([A-z]?)+|\.[A-z][+-]+/gi, word => `['${word.replace('.', '')}']`);
};
const generateThemeTemplate = (tokenKey, tokenObject, keys) => {
  const filteredKeys = keys.filter(key => key !== 'components');
  return _prettier.default.format(`
    import { tokens } from '../tokens'

    ${tokenKey === 'components' ? `
      ${filteredKeys.map(key => `import { ${key} } from './${key}'`).join(';')}

      const theme = {
        ${filteredKeys.map(key => `...${key}`).join(',')}
      }
    ` : ''}
  
    export const ${tokenKey} = ${formatObject(tokenObject)}
    `, prettierConfig);
};
exports.generateThemeTemplate = generateThemeTemplate;
const generateThemeIndexFile = keys => {
  return _prettier.default.format(`
      import { tokens } from '../tokens'
      ${keys.map(key => `import { ${key} } from './${key}'`).join(';')}
  
      export const theme = {
        ${keys.join(',')},
        tokens,
      }
    `, prettierConfig);
};
exports.generateThemeIndexFile = generateThemeIndexFile;